@@ -1,6 +1,6 @@
 package Net::Appliance::Session::Transport;
 {
-  $Net::Appliance::Session::Transport::VERSION = '3.122010';
+  $Net::Appliance::Session::Transport::VERSION = '3.122100';
 }
 
 {
@@ -57,7 +57,8 @@ sub connect {
     # optionally, log in to the remote host
     if ($self->do_login and not $self->prompt_looks_like('prompt')) {
 
-        if ($self->prompt_looks_like('user')) {
+        if ($self->nci->phrasebook->has_macro('user')
+            and $self->prompt_looks_like('user')) {
             die 'a set username is required to connect to this host'
                 if not $self->has_username;
 
@@ -67,7 +68,10 @@ sub connect {
         die 'a set password is required to connect to this host'
             if not $self->has_password;
 
-        $self->cmd($self->get_password, { match => 'prompt' });
+        # support for serial console servers where, after loggin in to the
+        # server, the console is asleep and needs waking up to show its prompt
+        $self->say($self->get_password);
+        $self->find_prompt($self->wake_up);
     }
 
     $self->prompt_looks_like('prompt')
